@@ -4,12 +4,13 @@ use warnings;
 
 use Getopt::Std;
 my %opts;
-getopts('i:I:M:d:', \%opts);
+getopts('i:I:M:d:vt', \%opts);
 
-die "Usage: arp-request.pl -i dstIp [ -I srcIp ] [ -M srcMac ] [ -d device ]\n"
+die "Usage: arp-request.pl -i dstIp [ -I srcIp ] [ -M srcMac ] [ -d device ] ".
+    "[ -v ] [ -t timeout ]\n"
    unless $opts{i};
 
-$Net::Pkt::Debug++;
+$Net::Pkt::Debug = 3 if $opts{v};
 
 $Net::Pkt::Dev = $opts{d};
 $Net::Pkt::Ip  = $opts{I};
@@ -30,21 +31,22 @@ use Net::Pkt::Dump;
 my $dump = Net::Pkt::Dump->new(
    filter             => $frame->getFilter,
    unlinkAfterAnalyze => 1,
+   callStart          => 1,
+   timeoutOnNext      => $opts{t} ? $opts{t} : 3,
 );
 
-$dump->start;
-
 print "Request:\n";
 $frame->ethPrint;
 $frame->arpPrint;
 $frame->send;
 
-$dump->stop;
-
-$dump->analyze;
-if (my $reply = $frame->recv) {
-   print "\nReply:\n";
-   $reply->ethPrint;
-   $reply->arpPrint;
-   print "\n", $reply->arpSrcIp, " is-at ", $reply->arpSrc, "\n";
+until ($Net::Pkt::Timeout) {
+   if ($dump->next && $frame->recv) {
+      print "\nReply:\n";
+      $frame->reply->ethPrint;
+      $frame->reply->arpPrint;
+      print "\n", $frame->reply->arpSrcIp, " is-at ", $frame->reply->arpSrc,
+            "\n";
+      last;
+   }
 }
