@@ -6,7 +6,7 @@ use Getopt::Std;
 my %opts;
 getopts('i:I:d:v', \%opts);
 
-die "Usage: icmp-echo.pl -i dstIp [ -I srcIp ] [ -d device ]\n"
+die "Usage: icmp-echo.pl -i dstIp [ -I srcIp ] [ -d device ] [ -v ]\n"
    unless $opts{i};
 
 $Net::Pkt::Debug = 3 if $opts{v};
@@ -27,25 +27,25 @@ my $ip = Net::Pkt::LayerIPv4->new(
 
 use Net::Pkt::LayerICMPv4 qw(/NETPKT_*/);
 my $echo = Net::Pkt::LayerICMPv4->new(
-   type           => NETPKT_ICMPv4_TYPE_ECHO_REQUEST,
-   data           => "test",
+   type => NETPKT_ICMPv4_TYPE_ECHO_REQUEST,
+   data => "test",
 );
 
 my $frame = Net::Pkt::Frame->new(l3 => $ip, l4 => $echo);
 
 use Net::Pkt::Dump;
 my $dump = Net::Pkt::Dump->new(
-   filter => $frame->getFilter,
+   filter             => $frame->getFilter,
    unlinkAfterAnalyze => 1,
+   callStart          => 1,
 );
 
-$dump->start;
-
 $frame->send;
 
-$dump->stop;
-
-$dump->analyze;
-if (my $reply = $frame->recv) {
-   $reply->l4->print;
+until ($Net::Pkt::Timeout) {
+   if ($dump->next && $frame->recv) {
+      print "Reply:\n";
+      $frame->reply->icmpPrint;
+      last;
+   }
 }
